==> atlassian-renderer-8.0.27-sources.jar: com/atlassian/renderer/v2/macro/code/CodeMacro.java <==
package com.atlassian.renderer.v2.macro.code;

import com.atlassian.renderer.RenderContext;
import com.atlassian.renderer.TokenType;
import com.atlassian.renderer.v2.RenderMode;
import com.atlassian.renderer.v2.RenderUtils;
import com.atlassian.renderer.v2.V2SubRenderer;
import com.atlassian.renderer.v2.components.HtmlEscaper;
import com.atlassian.renderer.v2.macro.MacroException;
import com.atlassian.renderer.v2.macro.basic.AbstractPanelMacro;
import com.opensymphony.util.TextUtils;

import java.util.List;
import java.util.Map;

public class CodeMacro extends AbstractPanelMacro {
    private static final String DEFAULT_LANG = "java";
    private SourceCodeFormatterRepository codeFormatterRepository;

    public CodeMacro(V2SubRenderer subRenderer, List<SourceCodeFormatter> formatters) {
        setCodeFormatterRepository(new SimpleSourceCodeFormatterRepository(formatters));
        setSubRenderer(subRenderer);
    }

    public void setCodeFormatterRepository(SourceCodeFormatterRepository codeFormatterRepository) {
        this.codeFormatterRepository = codeFormatterRepository;
    }

    public CodeMacro() {

    }

    public boolean suppressMacroRenderingDuringWysiwyg() {
        return false;
    }

    protected String getPanelCSSClass() {
        return "code panel";
    }

    protected String getPanelHeaderCSSClass() {
        return "codeHeader panelHeader";
    }

    protected String getPanelContentCSSClass() {
        return "codeContent panelContent";
    }

    public RenderMode getBodyRenderMode() {
        return RenderMode.allow(RenderMode.F_HTMLESCAPE);
    }

    public String execute(Map parameters, String body, RenderContext renderContext) throws MacroException {
        String language = getLanguage(parameters).toLowerCase();

        SourceCodeFormatter formatter = getFormatter(language);

        String preamble = "";
        String classAttr = "";
        if (formatter == null) {
            preamble = RenderUtils.blockError("Unable to find source-code formatter for language: " + language + ".", "Available languages are: " + TextUtils.join(", ", codeFormatterRepository.getAvailableLanguages()));
            formatter = getFormatter(DEFAULT_LANG);
        } else {
            classAttr = " class=\"code-" + HtmlEscaper.escapeAll(language, false) + "\"";
        }

        String code = body;
        if (code.startsWith("\n"))
            code = code.substring(1);
        if (code.endsWith("\n"))
            code = code.substring(0, code.length());

        return super.execute(parameters, preamble + "<pre" + classAttr + ">" + formatter.format(code, language) + "</pre>", renderContext);
    }

    @Override
    public TokenType getTokenType(Map parameters, String body, RenderContext context) {
        return TokenType.BLOCK;
    }

    private SourceCodeFormatter getFormatter(String language) {
        return codeFormatterRepository.getSourceCodeFormatter(language);
    }

    private String getLanguage(Map parameters) {
        String lang = (String) parameters.get("lang");

        if (!TextUtils.stringSet(lang)) {
            lang = (String) parameters.get("0");
        }

        if (!TextUtils.stringSet(lang)) {
            lang = DEFAULT_LANG;
        }

        return lang;
    }
}

==> atlassian-renderer-9.0.0-sources.jar: com/atlassian/renderer/v2/macro/code/CodeMacro.java <==
package com.atlassian.renderer.v2.macro.code;

import com.atlassian.renderer.RenderContext;
import com.atlassian.renderer.TokenType;
import com.atlassian.renderer.util.UnicodeEscapingTool;
import com.atlassian.renderer.v2.RenderMode;
import com.atlassian.renderer.v2.RenderUtils;
import com.atlassian.renderer.v2.V2SubRenderer;
import com.atlassian.renderer.v2.components.HtmlEscaper;
import com.atlassian.renderer.v2.macro.MacroException;
import com.atlassian.renderer.v2.macro.basic.AbstractPanelMacro;
import com.opensymphony.util.TextUtils;

import java.util.List;
import java.util.Map;

public class CodeMacro extends AbstractPanelMacro {
    private static final String DEFAULT_LANG = "java";
    private SourceCodeFormatterRepository codeFormatterRepository;

    public CodeMacro(V2SubRenderer subRenderer, List<SourceCodeFormatter> formatters) {
        setCodeFormatterRepository(new SimpleSourceCodeFormatterRepository(formatters));
        setSubRenderer(subRenderer);
    }

    public void setCodeFormatterRepository(SourceCodeFormatterRepository codeFormatterRepository) {
        this.codeFormatterRepository = codeFormatterRepository;
    }

    public CodeMacro() {

    }

    public boolean suppressMacroRenderingDuringWysiwyg() {
        return false;
    }

    protected String getPanelCSSClass() {
        return "code panel";
    }

    protected String getPanelHeaderCSSClass() {
        return "codeHeader panelHeader";
    }

    protected String getPanelContentCSSClass() {
        return "codeContent panelContent";
    }

    public RenderMode getBodyRenderMode() {
        return RenderMode.allow(RenderMode.F_HTMLESCAPE);
    }

    public String execute(Map parameters, String body, RenderContext renderContext) throws MacroException {
        String language = getLanguage(parameters).toLowerCase();

        SourceCodeFormatter formatter = getFormatter(language);

        String preamble = "";
        String classAttr = "";
        if (formatter == null) {
            preamble = RenderUtils.blockError("Unable to find source-code formatter for language: " + language + ".", "Available languages are: " + TextUtils.join(", ", codeFormatterRepository.getAvailableLanguages()));
            formatter = getFormatter(DEFAULT_LANG);
        } else {
            classAttr = " class=\"code-" + HtmlEscaper.escapeAll(language, false) + "\"";
        }

        String code = body;
        if (code.startsWith("\n"))
            code = code.substring(1);
        if (code.endsWith("\n"))
            code = code.substring(0, code.length());

        String formatted = renderContext.getUnicodeEscapingTool().escapeBidiCharacters(formatter.format(code, language));

        return super.execute(parameters, preamble + "<pre" + classAttr + ">" + formatted + "</pre>", renderContext);
    }

    @Override
    public TokenType getTokenType(Map parameters, String body, RenderContext context) {
        return TokenType.BLOCK;
    }

    private SourceCodeFormatter getFormatter(String language) {
        return codeFormatterRepository.getSourceCodeFormatter(language);
    }

    private String getLanguage(Map parameters) {
        String lang = (String) parameters.get("lang");

        if (!TextUtils.stringSet(lang)) {
            lang = (String) parameters.get("0");
        }

        if (!TextUtils.stringSet(lang)) {
            lang = DEFAULT_LANG;
        }

        return lang;
    }
}
